@@ -1,29 +1,112 @@
 package Perl::Dist::WiX::Asset::Distribution;
 
+=pod
+
+=head1 NAME
+
+Perl::Dist::WiX::Asset::Distribution - "Perl Distribution" asset for a Win32 Perl
+
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::Asset::Distribution version 1.250.
+
+=head1 SYNOPSIS
+
+  my $distribution = Perl::Dist::WiX::Asset::Distribution->new(
+      parent   => $dist,
+      name     => 'MSERGEANT/DBD-SQLite-1.14.tar.gz',
+	  mod_name => 'DBD::SQLite',
+      force    => 1,
+  );
+
+=head1 DESCRIPTION
+
+L<Perl::Dist::WiX|Perl::Dist::WiX> supports two methods for adding Perl modules to the
+installation. The main method is to install it via the CPAN shell.
+
+The second is to download, make, test and install the Perl distribution
+package independently, avoiding the use of the CPAN client. Unlike the
+CPAN installation method, installing the distribution directly does
+C<not> allow the installation of dependencies, or the ability to discover
+and install the most recent release of the module.
+
+This secondary method is primarily used to deal with cases where the CPAN
+shell either fails or does not yet exist. Installation of the Perl
+toolchain to get a working CPAN client is done exclusively using the
+direct method, as well as the installation of a few special case modules
+such as ones where the newest release is broken, but an older
+or a development release is known to be good.
+
+B<Perl::Dist::WiX::Asset::Distribution> is a data class that provides
+encapsulation and error checking for a "Perl Distribution" to be
+installed in a C<Perl::Dist::WiX>-created installer using this
+secondary method.
+
+It is normally created on the fly by the Perl::Dist::WiX
+C<install_distribution> method (and other things that call it).
+
+=cut
+
 use 5.008001;
 use Moose;
 use MooseX::Types::Moose qw( Str Bool ArrayRef Maybe );
 use File::Spec::Functions qw( catdir catfile );
+use Params::Util qw( _INSTANCE );
 
-# require Data::Dumper;
 require File::Remove;
 require URI;
 
-our $VERSION = '1.100';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.250';
+$VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::Asset';
 extends 'Perl::Dist::WiX::Asset::DistBase';
 
+=head1 METHODS
+
+This class is a L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>
+and shares its API.
+
+=head2 new
+
+The C<new> constructor takes a series of parameters, validates then
+and returns a new B<Perl::Dist::WiX::Asset::Distribution> object.
+
+It inherits all the parameters described in the 
+L<< Perl::Dist::WiX::Role::Asset->new|Perl::Dist::WiX::Role::Asset/new >> 
+method documentation, and adds the additional parameters described below.
+
+=head3 name
+
+The required C<name> param is the CPAN path to the distribution
+such as shown in the synopsis.
+
+The url to fetch from will be derived from the name.
+
+=cut
+
+
+
 has name => (
-	is       => 'ro',
+	is       => 'bare',
 	isa      => Str,
 	reader   => 'get_name',
 	required => 1,
 );
 
+
+
+=head3 mod_name
+
+The required C<mod_name> param is the name of the main module being 
+installed. This is used to create the fragment name.
+
+=cut
+
+
+
 has module_name => (
-	is       => 'ro',
+	is       => 'bare',
 	isa      => Maybe [Str],
 	reader   => 'get_module_name',
 	init_arg => 'mod_name',
@@ -31,14 +114,46 @@ has module_name => (
 	default  => sub { return $_[0]->_name_to_module(); },
 );
 
+
+
+=head3 force
+
+The optional boolean C<force> param allows you to specify that the tests
+should be skipped and the distribution installed without validating it.
+
+It defaults to the force() attribute of the parent.
+
+=cut
+
+
+
 has force => (
 	is      => 'ro',
 	isa     => Bool,
 	reader  => '_get_force',
 	lazy    => 1,
-	default => sub { !!$_[0]->_get_parent()->force },
+	default => sub { !!$_[0]->_get_parent()->force() },
 );
 
+
+
+=head3 automated_testing
+
+Many modules contain additional long-running tests, tests that require
+additional dependencies, or have differing behaviour when installing
+in a non-user automated environment.
+
+The optional C<automated_testing> param lets you specify that the
+module should be installed with the B<AUTOMATED_TESTING> environment
+variable set to true, to make the distribution behave properly in an
+automated environment (in cases where it doesn't otherwise).
+
+Defaults to false.
+
+=cut
+
+
+
 has automated_testing => (
 	is      => 'ro',
 	isa     => Bool,
@@ -46,6 +161,25 @@ has automated_testing => (
 	default => 0,
 );
 
+
+
+=head3 release_testing
+
+Some modules contain release-time only tests, that require even heavier
+additional dependencies compared to even the C<automated_testing> tests.
+
+The optional C<release_testing> param lets you specify that the module
+tests should be run with the additional C<RELEASE_TESTING> environment
+flag set.
+
+By default, C<release_testing> is set to false to squelch any accidental
+execution of release tests when L<Perl::Dist::WiX|Perl::Dist::WiX> itself 
+is being tested under C<RELEASE_TESTING>.
+
+=cut
+
+
+
 has release_testing => (
 	is      => 'ro',
 	isa     => Bool,
@@ -53,6 +187,20 @@ has release_testing => (
 	default => 0,
 );
 
+
+
+=head3 makefilepl_param
+
+Some distributions illegally require you to pass additional non-standard
+parameters when you invoke "perl Makefile.PL".
+
+The optional C<makefilepl_param> param should be a reference to an ARRAY
+where each element contains the argument to pass to the Makefile.PL.
+
+=cut
+
+
+
 has makefilepl_param => (
 	is      => 'ro',
 	isa     => ArrayRef,
@@ -60,6 +208,20 @@ has makefilepl_param => (
 	default => sub { return [] },
 );
 
+
+
+=head3 buildpl_param
+
+Some distributions require you to pass additional non-standard
+parameters when you invoke "perl Build.PL".
+
+The optional C<buildpl_param> param should be a reference to an ARRAY
+where each element contains the argument to pass to the Build.PL.
+
+=cut
+
+
+
 has buildpl_param => (
 	is      => 'ro',
 	isa     => ArrayRef,
@@ -67,12 +229,19 @@ has buildpl_param => (
 	default => sub { return [] },
 );
 
-#has inject => (
-#	is       => 'ro',
-#	isa      => Maybe['URI'],
-#	reader   => '_get_inject',
-#	default  => undef,
-#);
+
+
+=head3 packlist
+
+The optional C<packlist> param lets you specify whether this distribution 
+creates a packlist (which is a quick way to verify which files are installed
+by the distribution).
+
+This parameter defaults to true.
+
+=cut
+
+
 
 has packlist => (
 	is      => 'ro',
@@ -81,6 +250,20 @@ has packlist => (
 	default => 1,
 );
 
+
+
+=head3 overwritable
+
+Some distributions (ExtUtils::MakeMaker, for example) install files that
+are overwritten by distributions installed after it.
+
+The optional C<overwritable> param lets you spedify that this is the case, 
+and defaults to false.
+
+=cut
+
+
+
 has overwritable => (
 	is      => 'ro',
 	isa     => Bool,
@@ -88,10 +271,71 @@ has overwritable => (
 	default => 0,
 );
 
+
+
+sub BUILDARGS {
+	my $class = shift;
+	my %args;
+
+	if ( @_ == 1 && 'HASH' eq ref $_[0] ) {
+		%args = %{ $_[0] };
+	} elsif ( 0 == @_ % 2 ) {
+		%args = (@_);
+	} else {
+		PDWiX->throw( 'Parameters incorrect (not a hashref or hash) '
+			  . 'for Perl::Dist::WiX::Asset::Distribution' );
+	}
+
+	unless ( defined _INSTANCE( $args{parent}, 'Perl::Dist::WiX' ) ) {
+		PDWiX::Parameter->throw(
+			parameter =>
+			  'parent: missing or not a Perl::Dist::WiX instance',
+			where => '::Asset::Distribution->new',
+		);
+	}
+
+	if ( exists $args{url} ) {
+		PDWiX::Parameter->throw(
+			parameter =>
+'url: Passed in (please remove - it will be calculated from name)',
+			where => '::Asset::Distribution->new',
+		);
+	}
+
+	if ( exists $args{file} ) {
+		PDWiX::Parameter->throw(
+			parameter =>
+'file: Passed in (please remove - it will be calculated from name)',
+			where => '::Asset::Distribution->new',
+		);
+	}
+
+	# Map CPAN dist path to url
+	my $dist = $args{name};
+	if ( !defined $dist ) {
+		PDWiX::Parameter->throw(
+			parameter => 'name: Not defined',
+			where     => '::Asset::Distribution->new',
+		);
+	}
+
+	$args{parent}->trace_line( 2, "Using distribution path $dist\n" );
+	my $one = substr $dist, 0, 1;
+	my $two = substr $dist, 1, 1;
+	my $path =
+	  File::Spec::Unix->catfile( 'authors', 'id', $one, "$one$two", $dist,
+	  );
+	$args{url} = URI->new_abs( $path, $args{parent}->cpan() )->as_string();
+	$args{file} = $args{url};
+	$args{file} =~ s{.+/}{}ms;
+
+	return {%args};
+} ## end sub BUILDARGS
+
 sub BUILD {
 	my $self = shift;
 
-	if ( $self->get_name eq $self->_get_url
+	if ( $self->get_name() eq $self->_get_url()
 		and not _DIST( $self->get_name() ) )
 	{
 		PDWiX::Parameter->throw("Missing or invalid name param\n");
@@ -100,11 +344,28 @@ sub BUILD {
 	return;
 }
 
+
+# get_name is defined earlier, in the "has name =>" line.
+# Here works for documenting it.
+
+=head2 get_name
+
+This method returns the name of the module being installed, in order to use
+it in filenames.
+
+=head2 install
+
+The install method installs the distribution described by the
+B<Perl::Dist::WiX::Asset::Distribution> object and returns a list of files
+that were installed as a L<File::List::Object|File::List::Object> object.
+
+=cut
+
+
+
 sub install {
 	my $self = shift;
 
-#	print Data::Dumper->new([$self], [qw(*self)])->Indent(1)->Maxdepth(1)->Dump();
-
 	my $name      = $self->get_name();
 	my $build_dir = $self->_get_build_dir();
 
@@ -113,26 +374,31 @@ sub install {
 	my $filelist_sub;
 
 	if ( not $self->_get_packlist() ) {
-		$filelist_sub = File::List::Object->new->readdir(
-			catdir( $self->image_dir, 'perl' ) );
+		$filelist_sub =
+		  File::List::Object->new->readdir( $self->_dir('perl') );
 		$self->_trace_line( 5,
 			    "***** Module being installed $module"
 			  . " requires packlist => 0 *****\n" );
 	}
 
 	# Download the file
-	my $tgz = $self->_mirror(
+	my $tgz = $self->_mirror_url(
 		$self->_abs_uri( $self->_get_cpan() ),
 		$self->_get_modules_dir(),
 	);
 
+	# Does it exist? If not, throw an error here.
+	if ( not -f $tgz ) {
+		PDWiX->throw('The file from an attempted download does not exist');
+	}
+
 	# Where will it get extracted to
 	my $dist_path = $name;
+	$self->_add_to_distributions_installed($dist_path);
 	$dist_path =~ s{[.] tar [.] gz}{}msx;   # Take off extensions.
 	$dist_path =~ s{[.] zip}{}msx;
 	$dist_path =~ s{.+\/}{}msx;        # Take off directories.
 	my $unpack_to = catdir( $build_dir, $dist_path );
-	$self->_add_to_distributions_installed($dist_path);
 
 	# Extract the tarball
 	if ( -d $unpack_to ) {
@@ -187,7 +453,8 @@ sub install {
 		  $self->_get_automated_testing() ? 1 : undef;
 		local $ENV{RELEASE_TESTING} =
 		  $self->_get_release_testing() ? 1 : undef;
-		local $ENV{PERL_MM_USE_DEFAULT} = 1;
+		local $ENV{PERL_MM_USE_DEFAULT}    = 1;
+		local $ENV{PERL_MM_NONINTERACTIVE} = 1;
 
 		$self->_configure($buildpl);
 
@@ -200,8 +467,8 @@ sub install {
 	if ( $self->_get_packlist() ) {
 		$filelist = $self->_search_packlist($module);
 	} else {
-		$filelist = File::List::Object->new()
-		  ->readdir( catdir( $self->image_dir, 'perl' ) );
+		$filelist =
+		  File::List::Object->new()->readdir( $self->_dir('perl') );
 		$filelist->subtract($filelist_sub)->filter( $self->_filters );
 	}
 
@@ -223,135 +490,6 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
-=pod
-
-=head1 NAME
-
-Perl::Dist::WiX::Asset::Distribution - "Perl Distribution" asset for a Win32 Perl
-
-=head1 SYNOPSIS
-
-  my $distribution = Perl::Dist::WiX::Asset::Distribution->new(
-      name  => 'MSERGEANT/DBD-SQLite-1.14.tar.gz',
-      force => 1,
-  );
-
-=head1 DESCRIPTION
-
-L<Perl::Dist::WiX> supports two methods for adding Perl modules to the
-installation. The main method is to install it via the CPAN shell.
-
-The second is to download, make, test and install the Perl distribution
-package independently, avoiding the use of the CPAN client. Unlike the
-CPAN installation method, installing the distribution directly does
-C<not> allow the installation of dependencies, or the ability to discover
-and install the most recent release of the module.
-
-This secondary method is primarily used to deal with cases where the CPAN
-shell either fails or does not yet exist. Installation of the Perl
-toolchain to get a working CPAN client is done exclusively using the
-direct method, as well as the installation of a few special case modules
-such as ones where the newest release is broken, but an older
-or a development release is known to be good.
-
-B<Perl::Dist::WiX::Asset::Distribution> is a data class that provides
-encapsulation and error checking for a "Perl Distribution" to be
-installed in a L<Perl::Dist::WiX>-based Perl distribution using this
-secondary method.
-
-It is normally created on the fly by the Perl::Dist::WiX
-C<install_distribution> method (and other things that call it).
-
-The specification of the location to retrieve the package is done via
-the standard mechanism implemented in L<Perl::Dist::WiX::Role::Asset>.
-
-=head1 METHODS
-
-This class is a L<Perl::Dist::WiX::Role::Asset> and shares its API.
-
-=head2 new
-
-The C<new> constructor takes a series of parameters, validates then
-and returns a new B<Perl::Dist::WiX::Asset::Distribution> object.
-
-It inherits all the params described in the L<Perl::Dist::WiX::Role::Asset> 
-C<new> method documentation, and adds some additional params.
-
-=over 4
-
-=item name
-
-The required C<name> param is the name of the package for the purposes
-of identification.
-
-This should match the name of the Perl distribution without any version
-numbers. For example, "File-Spec" or "libwww-perl".
-
-Alternatively, the C<name> param can be a CPAN path to the distribution
-such as shown in the synopsis.
-
-In this case, the url to fetch from will be derived from the name.
-
-=item force
-
-Unlike in the CPAN client installation, in which all modules MUST pass
-their tests to be added, the secondary method allows for cases where
-it is known that the tests can be safely "forced".
-
-The optional boolean C<force> param allows you to specify that the tests
-should be skipped and the module installed without validating it.
-
-=item automated_testing
-
-Many modules contain additional long-running tests, tests that require
-additional dependencies, or have differing behaviour when installing
-in a non-user automated environment.
-
-The optional C<automated_testing> param lets you specify that the
-module should be installed with the B<AUTOMATED_TESTING> environment
-variable set to true, to make the distribution behave properly in an
-automated environment (in cases where it doesn't otherwise).
-
-=item release_testing
-
-Some modules contain release-time only tests, that require even heavier
-additional dependencies compared to even the C<automated_testing> tests.
-
-The optional C<release_testing> param lets you specify that the module
-tests should be run with the additional C<RELEASE_TESTING> environment
-flag set.
-
-By default, C<release_testing> is set to false to squelch any accidental
-execution of release tests when L<Perl::Dist::WiX> itself is being tested
-under C<RELEASE_TESTING>.
-
-=item makefilepl_param
-
-Some distributions illegally require you to pass additional non-standard
-parameters when you invoke "perl Makefile.PL".
-
-The optional C<makefilepl_param> param should be a reference to an ARRAY
-where each element contains the argument to pass to the Makefile.PL.
-
-=item buildpl_param
-
-Some distributions require you to pass additional non-standard
-parameters when you invoke "perl Build.PL".
-
-The optional C<buildpl_param> param should be a reference to an ARRAY
-where each element contains the argument to pass to the Build.PL.
-
-=back
-
-The C<new> method returns a B<Perl::Dist::WiX::Asset::Distribution> object,
-or throws an exception on error.
-
-=head2 install
-
-The install method installs the distribution described by the
-B<Perl::Dist::WiX::Asset::Distribution> object and returns a list of files
-that were installed as a L<File::List::Object> object.
-
 =head1 SUPPORT
 
 Bugs should be reported via the CPAN bug tracker at
@@ -368,11 +506,12 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX>, L<Perl::Dist::WiX::Role::Asset>
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>
 
 =head1 COPYRIGHT
 
-Copyright 2009 Curtis Jewell.
+Copyright 2009 - 2010 Curtis Jewell.
 
 Copyright 2007 - 2009 Adam Kennedy.
 
