@@ -8,13 +8,13 @@ Perl::Dist::WiX::DirectoryTree2 - Base directory tree for Perl::Dist::WiX.
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::DirectoryTree2 version 1.200002.
+This document describes Perl::Dist::WiX::DirectoryTree2 version 1.250.
 
 =head1 SYNOPSIS
 
 	$tree = Perl::Dist::WiX::DirectoryTree2->instance();
 	
-	# TODO: Add more.
+	# See each method for examples.
 
 =head1 DESCRIPTION
 
@@ -35,12 +35,14 @@ use 5.008001;
 use MooseX::Singleton;
 use Params::Util qw( _IDENTIFIER _STRING _INSTANCE );
 use File::Spec::Functions qw( catdir catpath splitdir splitpath );
-use MooseX::Types::Moose qw( Str );
+use MooseX::Types::Moose qw( Str HashRef );
 use MooseX::Types::Path::Class qw( Dir );
+use Perl::Dist::WiX::Types qw( DirectoryTag );
 use Perl::Dist::WiX::Tag::Directory;
 use WiX3::Exceptions;
+use Scalar::Util qw(weaken);
 
-our $VERSION = '1.200002';
+our $VERSION = '1.250';
 $VERSION =~ s/_//sm;
 
 with 'WiX3::Role::Traceable';
@@ -65,11 +67,10 @@ C<instance()> method.
 # This is private, but retrievable by 'get_root'.
 has _root => (
 	is       => 'bare',
-	isa      => 'Perl::Dist::WiX::Tag::Directory',
+	isa      => DirectoryTag,
 	reader   => 'get_root',
 	required => 1,
 	handles  => {
-		'search_dir'               => 'search_dir',
 		'get_directory_object'     => 'get_directory_object',
 		'_add_directory_recursive' => '_add_directory_recursive',
 		'_indent'                  => 'indent',
@@ -77,6 +78,32 @@ has _root => (
 );
 
 
+# This is private.
+has _cache => (
+	traits   => ['Hash'],
+	is       => 'ro',
+	isa      => HashRef [DirectoryTag],
+	init_arg => undef,
+	default  => sub { {} },
+	handles  => {
+		'_get_cache_entry' => 'get',
+		'_is_in_cache'     => 'exists',
+	},
+);
+
+
+sub _add_to_cache {
+	my $self = shift;
+	my ( $key, $value );
+	while ( 0 < scalar @_ ) {
+		$key   = shift;
+		$value = shift;
+		weaken( $self->_cache()->{$key} = $value );
+	}
+	return;
+}
+
+
 =head3 app_dir
 
 This is set to the distribution's image_dir (where the distribution is
@@ -165,8 +192,8 @@ Returns the previously created directory tree.
 
 	my $directory_object = $tree->get_root();
 	
-Gets the L<Perl::Dist::WiX::Directory|Perl::Dist::WiX::Directory> object at
-the root of the tree.
+Gets the L<Perl::Dist::WiX::Tag::Directory|Perl::Dist::WiX::Tag::Directory> 
+object at the root of the tree.
 	
 =head2 as_string
 
@@ -206,7 +233,7 @@ sub initialize_tree {
 			noprefix => 1,
 			path     => $self->_get_app_dir()->stringify(),
 		} );
-	$self->get_root()->add_directory( {
+	my $app_menu = $self->get_root()->add_directory( {
 			id       => 'ProgramMenuFolder',
 			noprefix => 1,
 		}
@@ -216,6 +243,11 @@ sub initialize_tree {
 		} );
 
 #<<<
+	$app_menu->add_directories_id(
+		'App_Menu_Tools',    'Tools',
+		'App_Menu_Websites', 'Related Websites',
+	);
+
 	$branch->add_directories_id(
 		'Perl',      'perl',
 		'Toolchain', 'c',
@@ -295,7 +327,7 @@ sub initialize_short_tree {
 			noprefix => 1,
 			path     => $self->_get_app_dir()->stringify(),
 		} );
-	$self->get_root()->add_directory( {
+	my $app_menu = $self->get_root()->add_directory( {
 			id       => 'ProgramMenuFolder',
 			noprefix => 1,
 		}
@@ -305,6 +337,11 @@ sub initialize_short_tree {
 		} );
 
 #<<<
+	$app_menu->add_directories_id(
+		'App_Menu_Tools',    'Tools',
+		'App_Menu_Websites', 'Related Websites',
+	);
+
 	$branch->add_directories_id(
 		'Win32',     'win32',
 		'Perl',      'perl',
@@ -367,8 +404,11 @@ sub add_directory {
 
 =head2 add_root_directory
 
-TODO
+	$self->add_root_directory('Id', 'directory');
 
+Adds a directory entry with the ID and directory name given
+immediately under the main installation directory.
+	
 =cut
 
 
@@ -415,11 +455,64 @@ sub add_merge_module {
 
 	$directory_object->add_child_tag($mm);
 
-	return;
+	return 1;
 } ## end sub add_merge_module
 
 
 
+=head2 search_dir
+
+Calls L<Perl::Dist::WiX::Directory's search_dir routine|Perl::Dist::WiX::Directory/search_dir>
+on the root directory with the parameters given.
+
+Checks a cache of successful searches if descend and exact are both 1.
+
+=cut
+
+
+
+sub search_dir {
+	my $self = shift;
+
+	my %args;
+
+	if ( @_ == 1 && 'HASH' eq ref $_[0] ) {
+		%args = %{ $_[0] };
+	} elsif ( @_ % 2 == 0 ) {
+		%args = @_;
+	} else {
+		PDWiX->throw('Invalid number of arguments to search_dir');
+	}
+
+	# Set defaults for parameters.
+	my $path_to_find = _STRING( $args{'path_to_find'} )
+	  || PDWiX::Parameter->throw(
+		parameter => 'path_to_find',
+		where     => '::DirectoryTree2->search_dir'
+	  );
+	my $descend = $args{descend} || 1;
+	my $exact   = $args{exact}   || 0;
+
+	if ( ( 1 == $descend ) and ( 1 == $exact ) ) {
+
+		# Check cache, return what's in it if needed.
+		if ( $self->_is_in_cache($path_to_find) ) {
+			$self->trace_line( 3,
+				"Found $path_to_find in directory tree cache.\n" );
+			return $self->_get_cache_entry($path_to_find);
+		}
+	}
+
+	my $dir = $self->get_root()->search_dir(@_);
+
+	if ( ( defined $dir ) and ( 1 == $descend ) and ( 1 == $exact ) ) {
+		$self->_add_to_cache( $path_to_find, $dir );
+	}
+
+	return $dir;
+} ## end sub search_dir
+
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -427,16 +520,11 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
-=head2 get_directory_object
+head2 get_directory_object
 
 Calls L<Perl::Dist::WiX::Directory's get_directory_object routine|Perl::Dist::WiX::Directory/get_directory_object>
 on the root directory with the parameters given.
 
-=head2 search_dir
-
-Calls L<Perl::Dist::WiX::Directory's search_dir routine|Perl::Dist::WiX::Directory/search_dir>
-on the root directory with the parameters given.
-
 =head1 DIAGNOSTICS
 
 See Perl::Dist::WiX's L<DIAGNOSTICS section|Perl::Dist::WiX/DIAGNOSTICS> for 
