@@ -6,6 +6,10 @@ package Perl::Dist::WiX::Role::NonURLAsset;
 
 Perl::Dist::WiX::Role::NonURLAsset - Role for assets that do not require URL's.
 
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::Role::NonURLAsset version 1.250.
+
 =head1 SYNOPSIS
 
 	# Since this is a role, it is composed into classes that use it.
@@ -23,7 +27,7 @@ L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
 use 5.008001;
 use Moose::Role;
 use File::Spec::Functions qw( rel2abs catdir catfile );
-use MooseX::Types::Moose qw( Str );
+use MooseX::Types::Moose qw( Str Maybe );
 use Params::Util qw( _INSTANCE );
 use English qw( -no_match_vars );
 require File::List::Object;
@@ -33,7 +37,7 @@ require Perl::Dist::WiX::Exceptions;
 require URI;
 require URI::file;
 
-our $VERSION = '1.200';
+our $VERSION = '1.250';
 $VERSION =~ s/_//sm;
 
 
@@ -90,6 +94,7 @@ has parent => (
 		'_patch_file'       => 'patch_file',
 		'_build'            => 'execute_build',
 		'_make'             => 'execute_make',
+		'_use_sqlite'       => '_use_sqlite',
 		'_add_to_distributions_installed' =>
 		  '_add_to_distributions_installed',
 	},
@@ -98,6 +103,27 @@ has parent => (
 
 
 
+=head2 packlist_location
+
+Some distributions create their packlist in an odd location (one 
+not specified by the main module in the distribution.)
+
+This optional parameter specifies the directory the packlist is in as a 
+relative directory to C<image_dir()> . "/I<install location>/lib/author".
+
+=cut
+
+
+
+has packlist_location => (
+	is      => 'ro',
+	isa     => Maybe [Str],
+	reader  => '_get_packlist_location',
+	default => undef,
+);
+
+
+
 =head1 METHODS
 
 =head2 install
@@ -141,6 +167,25 @@ EOF
 		catdir( $image_dir, qw{perl        lib auto}, @module_dirs ),
 	);
 
+	my $packlist_location = $self->_get_packlist_location();
+	if ( defined $packlist_location ) {
+		push @dirs,
+		  (
+			catdir(
+				$image_dir, qw{perl vendor lib auto},
+				$packlist_location
+			),
+			catdir(
+				$image_dir, qw{perl site   lib auto},
+				$packlist_location
+			),
+			catdir(
+				$image_dir, qw{perl        lib auto},
+				$packlist_location
+			),
+		  );
+	} ## end if ( defined $packlist_location)
+
 	# What file exists, if any?
 	my $packlist;
   DIR:
