@@ -6,7 +6,7 @@ Perl::Dist::WiX::Types - Public types used in Perl::Dist::WiX.
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Types version 1.200.
+This document describes Perl::Dist::WiX::Types version 1.250.
 
 =head1 SYNOPSIS
 
@@ -28,12 +28,13 @@ use MooseX::Types -declare => [ qw(
 	  _NoDoubleSlashes _NoSpaces _NoForwardSlashes _NoSlashAtEnd _NotRootDir
 	  ExistingSubdirectory ExistingDirectory_Spaceless
 	  ExistingDirectory_SaneSlashes
+	  DirectoryRef DirectoryTag
 	  ) ];
 use MooseX::Types::Moose qw( Str Object ArrayRef );
 use MooseX::Types::Path::Class qw( Dir File );
 use Template qw();
 
-our $VERSION = '1.200';
+our $VERSION = '1.250';
 $VERSION =~ s/_//ms;
 
 =head2 ExistingDirectory
@@ -115,11 +116,11 @@ coerce ExistingFile,
   from Str,      via { to_File($_) },
   from ArrayRef, via { to_File($_) };
 
-=head2 Template
+=head2 TemplateObj
 
 	has bar => (
 		is => 'ro',
-		isa => Template,
+		isa => TemplateObj,
 		#...
 	);
 
@@ -131,6 +132,10 @@ subtype TemplateObj,
   where { $_->isa('Template') },
   message {'Template is not the correct type of object'};
 
+class_type DirectoryRef, { class => 'Perl::Dist::WiX::Tag::DirectoryRef' };
+
+class_type DirectoryTag, { class => 'Perl::Dist::WiX::Tag::Directory' };
+
 1;
 
 __END__
